Module blaxel.core.client.models.job_execution_metadata
=======================================================

Classes
-------

`JobExecutionMetadata(cluster: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, completed_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, created_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, deleted_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, expired_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, id: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, job: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, started_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, updated_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, workspace: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Job execution metadata
    
    Attributes:
        cluster (Union[Unset, str]): Cluster ID
        completed_at (Union[Unset, str]): Completion timestamp
        created_at (Union[Unset, str]): Creation timestamp
        deleted_at (Union[Unset, str]): Deletion timestamp
        expired_at (Union[Unset, str]): Expiration timestamp
        id (Union[Unset, str]): Execution ID
        job (Union[Unset, str]): Job name
        started_at (Union[Unset, str]): Start timestamp
        updated_at (Union[Unset, str]): Last update timestamp
        workspace (Union[Unset, str]): Workspace ID
    
    Method generated by attrs for class JobExecutionMetadata.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `cluster: blaxel.core.client.types.Unset | str`
    :

    `completed_at: blaxel.core.client.types.Unset | str`
    :

    `created_at: blaxel.core.client.types.Unset | str`
    :

    `deleted_at: blaxel.core.client.types.Unset | str`
    :

    `expired_at: blaxel.core.client.types.Unset | str`
    :

    `id: blaxel.core.client.types.Unset | str`
    :

    `job: blaxel.core.client.types.Unset | str`
    :

    `started_at: blaxel.core.client.types.Unset | str`
    :

    `updated_at: blaxel.core.client.types.Unset | str`
    :

    `workspace: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :